@@ -22,6 +22,8 @@
 
  */
 
+$VERSION='$Id$';
+
 ////////// READ OPTIONAL CONFIGURATION FILE ////////////
 if (file_exists("apc.conf.php")) include("apc.conf.php");
 ////////////////////////////////////////////////////////
@@ -64,7 +66,7 @@ $time = time();
 $host = php_uname('n');
 if($host) { $host = '('.$host.')'; }
 if (isset($_SERVER['SERVER_ADDR'])) {
-	$host .= ' ('.$_SERVER['SERVER_ADDR'].')';
+  $host .= ' ('.$_SERVER['SERVER_ADDR'].')';
 }
 
 // operation constants
@@ -112,15 +114,15 @@ if (empty($_REQUEST)) {
 // check parameter syntax
 foreach($vardom as $var => $dom) {
 	if (!isset($_REQUEST[$var])) {
-		$MYREQUEST[$var]=null;
+		$MYREQUEST[$var]=NULL;
 	} else if (!is_array($_REQUEST[$var]) && preg_match($dom.'D',$_REQUEST[$var])) {
 		$MYREQUEST[$var]=$_REQUEST[$var];
 	} else {
-		$MYREQUEST[$var]=$_REQUEST[$var]=null;
+		$MYREQUEST[$var]=$_REQUEST[$var]=NULL;
 	}
 }
 
-// check parameter semantics
+// check parameter sematics
 if (empty($MYREQUEST['SCOPE'])) $MYREQUEST['SCOPE']="A";
 if (empty($MYREQUEST['SORT1'])) $MYREQUEST['SORT1']="H";
 if (empty($MYREQUEST['SORT2'])) $MYREQUEST['SORT2']="D";
@@ -194,25 +196,25 @@ header("Cache-Control: post-check=0, pre-check=0", false);
 header("Pragma: no-cache");                                    // HTTP/1.0
 
 function duration($ts) {
-	global $time;
-	$years = (int)((($time - $ts)/(7*86400))/52.177457);
-	$rem = (int)(($time-$ts)-($years * 52.177457 * 7 * 86400));
-	$weeks = (int)(($rem)/(7*86400));
-	$days = (int)(($rem)/86400) - $weeks*7;
-	$hours = (int)(($rem)/3600) - $days*24 - $weeks*7*24;
-	$mins = (int)(($rem)/60) - $hours*60 - $days*24*60 - $weeks*7*24*60;
-	$str = '';
-	if($years==1) $str .= "$years year, ";
-	if($years>1) $str .= "$years years, ";
-	if($weeks==1) $str .= "$weeks week, ";
-	if($weeks>1) $str .= "$weeks weeks, ";
-	if($days==1) $str .= "$days day,";
-	if($days>1) $str .= "$days days,";
-	if($hours == 1) $str .= " $hours hour and";
-	if($hours>1) $str .= " $hours hours and";
-	if($mins == 1) $str .= " 1 minute";
-	else $str .= " $mins minutes";
-	return $str;
+    global $time;
+    $years = (int)((($time - $ts)/(7*86400))/52.177457);
+    $rem = (int)(($time-$ts)-($years * 52.177457 * 7 * 86400));
+    $weeks = (int)(($rem)/(7*86400));
+    $days = (int)(($rem)/86400) - $weeks*7;
+    $hours = (int)(($rem)/3600) - $days*24 - $weeks*7*24;
+    $mins = (int)(($rem)/60) - $hours*60 - $days*24*60 - $weeks*7*24*60;
+    $str = '';
+    if($years==1) $str .= "$years year, ";
+    if($years>1) $str .= "$years years, ";
+    if($weeks==1) $str .= "$weeks week, ";
+    if($weeks>1) $str .= "$weeks weeks, ";
+    if($days==1) $str .= "$days day,";
+    if($days>1) $str .= "$days days,";
+    if($hours == 1) $str .= " $hours hour and";
+    if($hours>1) $str .= " $hours hours and";
+    if($mins == 1) $str .= " 1 minute";
+    else $str .= " $mins minutes";
+    return $str;
 }
 
 // create graphics
@@ -232,7 +234,7 @@ if (isset($MYREQUEST['IMG']))
 
 
 		if (function_exists("imagefilledarc")) {
-			// exists only if GD 2.0.1 is available
+			// exists only if GD 2.0.1 is avaliable
 			imagefilledarc($im, $centerX+1, $centerY+1, $diameter, $diameter, $start, $end, $color1, IMG_ARC_PIE);
 			imagefilledarc($im, $centerX, $centerY, $diameter, $diameter, $start, $end, $color2, IMG_ARC_PIE);
 			imagefilledarc($im, $centerX, $centerY, $diameter, $diameter, $start, $end, $color1, IMG_ARC_NOFILL|IMG_ARC_EDGED);
@@ -517,7 +519,6 @@ body,p,td,th,input,submit { font-size:0.8em;font-family:arial,helvetica,sans-ser
 td { vertical-align:top }
 a { color:black; font-weight:none; text-decoration:none; }
 a:hover { text-decoration:underline; }
-a.entry-info:hover { text-decoration:none; }
 div.content { padding:1em 1em 1em 1em; position:absolute; width:97%; z-index:100; }
 
 
@@ -643,7 +644,6 @@ div.info table th {
 	padding:0.1em 1em 0.1em 1em;
 	}
 div.info table th a.sortable { color:black; }
-div.info table tr.sticky { position: sticky; top: 0; }
 div.info table tr.tr-0 { background:rgb(238,238,238); }
 div.info table tr.tr-1 { background:rgb(221,221,221); }
 div.info table td { padding:0.3em 1em 0.3em 1em; }
@@ -760,9 +760,7 @@ case OB_HOST_STATS:
 	$apcversion = phpversion('apcu');
 	$phpversion = phpversion();
 	$number_vars = $cache['num_entries'];
-	$size_vars = bsize($cache['mem_size']);
-	$num_hits_and_misses = $cache['num_hits'] + $cache['num_misses'];
-	$num_hits_and_misses = 0 >= $num_hits_and_misses ? 1 : $num_hits_and_misses;
+    $size_vars = bsize($cache['mem_size']);
 	$i=0;
 	echo <<< EOB
 		<div class="info div1"><h2>General Cache Information</h2>
@@ -783,6 +781,7 @@ EOB;
 EOB;
 	echo   '<tr class=tr-1><td class=td-0>Start Time</td><td>',date(DATE_FORMAT,$cache['start_time']),'</td></tr>';
 	echo   '<tr class=tr-0><td class=td-0>Uptime</td><td>',duration($cache['start_time']),'</td></tr>';
+	echo   '<tr class=tr-1><td class=td-0>File Upload Support</td><td>',$cache['file_upload_progress'],'</td></tr>';
 	echo <<<EOB
 		</tbody></table>
 		</div>
@@ -839,11 +838,11 @@ EOB;
 			: "",
 		'<tr>',
 		'<td class=td-0><span class="green box">&nbsp;</span>Free: ',bsize($mem_avail).sprintf(" (%.1f%%)",$mem_avail*100/$mem_size),"</td>\n",
-		'<td class=td-1><span class="green box">&nbsp;</span>Hits: ',$cache['num_hits'].@sprintf(" (%.1f%%)",$cache['num_hits']*100/$num_hits_and_misses),"</td>\n",
+		'<td class=td-1><span class="green box">&nbsp;</span>Hits: ',$cache['num_hits'].@sprintf(" (%.1f%%)",$cache['num_hits']*100/($cache['num_hits']+$cache['num_misses'])),"</td>\n",
 		'</tr>',
 		'<tr>',
 		'<td class=td-0><span class="red box">&nbsp;</span>Used: ',bsize($mem_used).sprintf(" (%.1f%%)",$mem_used *100/$mem_size),"</td>\n",
-		'<td class=td-1><span class="red box">&nbsp;</span>Misses: ',$cache['num_misses'].@sprintf(" (%.1f%%)",$cache['num_misses']*100/$num_hits_and_misses),"</td>\n";
+		'<td class=td-1><span class="red box">&nbsp;</span>Misses: ',$cache['num_misses'].@sprintf(" (%.1f%%)",$cache['num_misses']*100/($cache['num_hits']+$cache['num_misses'])),"</td>\n";
 	echo <<< EOB
 		</tr>
 		</tbody></table>
@@ -864,9 +863,9 @@ EOB;
 				++$nseg;
 			}
 			$ptr = $block['offset'] + $block['size'];
-			/* Only consider blocks <5M for the fragmentation % */
-			if($block['size']<(5*1024*1024)) $fragsize+=$block['size'];
-			$freetotal+=$block['size'];
+                        /* Only consider blocks <5M for the fragmentation % */
+                        if($block['size']<(5*1024*1024)) $fragsize+=$block['size'];
+                        $freetotal+=$block['size'];
 		}
 		$freeseg += count($mem['block_lists'][$i]);
 	}
@@ -888,14 +887,14 @@ EOB;
 		</td>
 		</tr>
 EOB;
-		if(isset($mem['adist'])) {
-			foreach($mem['adist'] as $i=>$v) {
-				$cur = pow(2,$i); $nxt = pow(2,$i+1)-1;
-				if($i==0) $range = "1";
-				else $range = "$cur - $nxt";
-				echo "<tr><th align=right>$range</th><td align=right>$v</td></tr>\n";
-			}
-		}
+        if(isset($mem['adist'])) {
+          foreach($mem['adist'] as $i=>$v) {
+            $cur = pow(2,$i); $nxt = pow(2,$i+1)-1;
+            if($i==0) $range = "1";
+            else $range = "$cur - $nxt";
+            echo "<tr><th align=right>$range</th><td align=right>$v</td></tr>\n";
+          }
+        }
         echo <<<EOB
 		</tbody></table>
 		</div>
@@ -909,7 +908,7 @@ EOB;
 // -----------------------------------------------
 case OB_USER_CACHE:
 	if (!$AUTHENTICATED) {
-		echo '<div class="error">You need to login to see the user values here!<br/>&nbsp;<br/>';
+    echo '<div class="error">You need to login to see the user values here!<br/>&nbsp;<br/>';
 		put_login_link("Login now!");
 		echo '</div>';
 		break;
@@ -937,7 +936,7 @@ EOB;
 		"<option value=C",$MYREQUEST['SORT1']=='C' ? " selected":"",">Created at</option>",
 		"<option value=D",$MYREQUEST['SORT1']=='D' ? " selected":"",">Deleted at</option>";
 	if($fieldname=='info') echo
-		"<option value=T",$MYREQUEST['SORT1']=='T' ? " selected":"",">Timeout</option>";
+		"<option value=D",$MYREQUEST['SORT1']=='T' ? " selected":"",">Timeout</option>";
 	echo
 		'</select>',
 		'<select name=SORT2>',
@@ -958,19 +957,19 @@ EOB;
 		'&nbsp;<input type=submit value="GO!">',
 		'</form></div>';
 
-	if (isset($MYREQUEST['SEARCH'])) {
-		// Don't use preg_quote because we want the user to be able to specify a
-		// regular expression subpattern.
-		$MYREQUEST['SEARCH_REGEX'] = '/'.str_replace('/', '\\/', $MYREQUEST['SEARCH']).'/i';
-		if (preg_match($MYREQUEST['SEARCH_REGEX'], 'test') === false) {
-			echo '<div class="error">Error: enter a valid regular expression as a search query.</div>';
-			break;
-		}
-	}
+  if (isset($MYREQUEST['SEARCH'])) {
+   // Don't use preg_quote because we want the user to be able to specify a
+   // regular expression subpattern.
+   $MYREQUEST['SEARCH'] = '/'.str_replace('/', '\\/', $MYREQUEST['SEARCH']).'/i';
+   if (preg_match($MYREQUEST['SEARCH'], 'test') === false) {
+     echo '<div class="error">Error: enter a valid regular expression as a search query.</div>';
+     break;
+   }
+  }
 
-	echo
+  echo
 		'<div class="info"><table cellspacing=0><tbody>',
-		'<tr class="sticky">',
+		'<tr>',
 		'<th>',sortheader('S',$fieldheading,  "&OB=".$MYREQUEST['OB']),'</th>',
 		'<th>',sortheader('H','Hits',         "&OB=".$MYREQUEST['OB']),'</th>',
 		'<th>',sortheader('Z','Size',         "&OB=".$MYREQUEST['OB']),'</th>',
@@ -1018,51 +1017,45 @@ EOB;
 		// output list
 		$i=0;
 		foreach($list as $k => $entry) {
-			if(empty($MYREQUEST['SEARCH_REGEX']) || preg_match($MYREQUEST['SEARCH_REGEX'], $entry[$fieldname]) != 0) {
-				$sh=md5($entry["info"]);
-				$field_value = htmlentities(strip_tags($entry[$fieldname],''), ENT_QUOTES, 'UTF-8');
-				if ($sh == $MYREQUEST["SH"]) {
-					$shstr = "";
-				} else {
-					$shstr = "&SH=" . $sh;
-				}
-				$href = "$MY_SELF&OB=" . $MYREQUEST['OB'] . (!empty($MYREQUEST['SEARCH']) ? "&SEARCH=" . urlencode($MYREQUEST['SEARCH']) : '') . $shstr . "#key-" . $sh;
-				echo
-					'<tr id="key-'. $sh .'" class=tr-',$i%2,'>',
-					"<td class=td-0><a href=\"$href\">",$field_value,'</a></td>',
-					'<td class="td-n center">',$entry['num_hits'],'</td>',
-					'<td class="td-n right">',$entry['mem_size'],'</td>',
-					'<td class="td-n center">',date(DATE_FORMAT,$entry['access_time']),'</td>',
-					'<td class="td-n center">',date(DATE_FORMAT,$entry['mtime']),'</td>',
-					'<td class="td-n center">',date(DATE_FORMAT,$entry['creation_time']),'</td>';
+      if(!$MYREQUEST['SEARCH'] || preg_match($MYREQUEST['SEARCH'], $entry[$fieldname]) != 0) {
+		$sh=md5($entry["info"]);
+        $field_value = htmlentities(strip_tags($entry[$fieldname],''), ENT_QUOTES, 'UTF-8');
+        echo
+          '<tr id="key-'. $sh .'" class=tr-',$i%2,'>',
+          "<td class=td-0><a href=\"$MY_SELF&OB=",$MYREQUEST['OB'],"&SH=",$sh,"#key-". $sh ."\">",$field_value,'</a></td>',
+          '<td class="td-n center">',$entry['num_hits'],'</td>',
+          '<td class="td-n right">',$entry['mem_size'],'</td>',
+          '<td class="td-n center">',date(DATE_FORMAT,$entry['access_time']),'</td>',
+          '<td class="td-n center">',date(DATE_FORMAT,$entry['mtime']),'</td>',
+          '<td class="td-n center">',date(DATE_FORMAT,$entry['creation_time']),'</td>';
 
-				if($fieldname=='info') {
-					if($entry['ttl']) {
-						echo '<td class="td-n center">'.$entry['ttl'].' seconds</td>';
-					} else {
-						echo '<td class="td-n center">None</td>';
-					}
-				}
-				if ($entry['deletion_time']) {
-					echo '<td class="td-last center">', date(DATE_FORMAT,$entry['deletion_time']), '</td>';
-				} else if ($MYREQUEST['OB'] == OB_USER_CACHE) {
-					echo '<td class="td-last center">';
-					echo '[<a href="', $MY_SELF, '&OB=', $MYREQUEST['OB'], '&DU=', urlencode($entry[$fieldkey]), '">Delete Now</a>]';
-					echo '</td>';
-				} else {
-					echo '<td class="td-last center"> &nbsp; </td>';
-				}
-				echo '</tr>';
-				if ($sh == $MYREQUEST["SH"]) {
-					echo '<tr>';
-					echo '<td colspan="7"><a class="entry-info" href="'.$href.'"><pre>'.htmlentities(print_r(apcu_fetch($entry['info']), 1)).'</pre></a></td>';
-					echo '</tr>';
-				}
-				$i++;
-				if ($i == $MYREQUEST['COUNT']) {
-					break;
-				}
-			}
+        if($fieldname=='info') {
+          if($entry['ttl'])
+            echo '<td class="td-n center">'.$entry['ttl'].' seconds</td>';
+          else
+            echo '<td class="td-n center">None</td>';
+        }
+        if ($entry['deletion_time']) {
+
+          echo '<td class="td-last center">', date(DATE_FORMAT,$entry['deletion_time']), '</td>';
+        } else if ($MYREQUEST['OB'] == OB_USER_CACHE) {
+
+          echo '<td class="td-last center">';
+          echo '[<a href="', $MY_SELF, '&OB=', $MYREQUEST['OB'], '&DU=', urlencode($entry[$fieldkey]), '">Delete Now</a>]';
+          echo '</td>';
+        } else {
+          echo '<td class="td-last center"> &nbsp; </td>';
+        }
+        echo '</tr>';
+		if ($sh == $MYREQUEST["SH"]) {
+			echo '<tr>';
+			echo '<td colspan="7"><pre>'.htmlentities(print_r(apcu_fetch($entry['info']), 1)).'</pre></td>';
+			echo '</tr>';
+		}
+        $i++;
+        if ($i == $MYREQUEST['COUNT'])
+          break;
+      }
 		}
 
 	} else {
@@ -1092,16 +1085,16 @@ case OB_VERSION_CHECK:
 		<th></th>
 		</tr>
 EOB;
-	if (defined('PROXY')) {
-		$ctxt = stream_context_create( array( 'http' => array( 'proxy' => PROXY, 'request_fulluri' => true ) ) );
-		$rss = @file_get_contents("http://pecl.php.net/feeds/pkg_apcu.rss", false, $ctxt);
-	} else {
-		$rss = @file_get_contents("http://pecl.php.net/feeds/pkg_apcu.rss");
-	}
+  if (defined('PROXY')) {
+    $ctxt = stream_context_create( array( 'http' => array( 'proxy' => PROXY, 'request_fulluri' => True ) ) );
+    $rss = @file_get_contents("http://pecl.php.net/feeds/pkg_apcu.rss", False, $ctxt);
+  } else {
+    $rss = @file_get_contents("http://pecl.php.net/feeds/pkg_apcu.rss");
+  }
 	if (!$rss) {
 		echo '<tr class="td-last center"><td>Unable to fetch version information.</td></tr>';
 	} else {
-		$apcversion = phpversion('apcu');
+		$apcversion = phpversion('apc');
 
 		preg_match('!<title>APCu ([0-9.]+)</title>!', $rss, $match);
 		echo '<tr class="tr-0 center"><td>';
@@ -1119,19 +1112,18 @@ EOB;
 		echo '<tr class="tr-0"><td><h3>Change Log:</h3><br/>';
 
 		preg_match_all('!<(title|description)>([^<]+)</\\1>!', $rss, $match);
-		$changelog = $match[2];
+		next($match[2]); next($match[2]);
 
-		for ($j = 2; $j + 1 < count($changelog); $j += 2) {
-			$v = $changelog[$j];
-			list(, $ver) = explode(' ', $v, 2);
+		while (list(,$v) = each($match[2])) {
+			list(,$ver) = explode(' ', $v, 2);
 			if ($i < 0 && version_compare($apcversion, $ver, '>=')) {
 				break;
 			} else if (!$i--) {
 				break;
 			}
-			$changes = $changelog[$j + 1];
 			echo "<b><a href=\"http://pecl.php.net/package/APCu/$ver\">".htmlspecialchars($v, ENT_QUOTES, 'UTF-8')."</a></b><br><blockquote>";
-			echo nl2br(htmlspecialchars($changes, ENT_QUOTES, 'UTF-8'))."</blockquote>";
+			echo nl2br(htmlspecialchars(current($match[2]), ENT_QUOTES, 'UTF-8'))."</blockquote>";
+			next($match[2]);
 		}
 		echo '</td></tr>';
 	}
@@ -1143,12 +1135,12 @@ EOB;
 
 }
 
-	echo <<< EOB
+echo <<< EOB
 	</div>
 EOB;
 
 ?>
 
-<!-- <?php echo "\nBased on APCGUI By R.Becker\n"?> -->
+<!-- <?php echo "\nBased on APCGUI By R.Becker\n$VERSION\n"?> -->
 </body>
 </html>
