@@ -32,6 +32,7 @@
 #include "apc_sma.h"
 #include "apc_globals.h"
 #include "apc_strings.h"
+#include "apc_time.h"
 #include "php_scandir.h"
 #include "SAPI.h"
 #include "TSRM.h"
@@ -115,7 +116,7 @@ static inline void free_entry(apc_cache_t *cache, apc_cache_entry_t *entry) {
 /* {{{ apc_cache_hash_slot
  Note: These calculations can and should be done outside of a lock */
 static inline void apc_cache_hash_slot(
-		apc_cache_t* cache, zend_string *key, zend_ulong* hash, zend_ulong* slot) {
+		apc_cache_t* cache, zend_string *key, zend_ulong* hash, size_t* slot) {
 	*hash = ZSTR_HASH(key);
 	*slot = *hash % cache->nslots;
 } /* }}} */
@@ -272,7 +273,7 @@ PHP_APCU_API int APC_UNSERIALIZER_NAME(php) (APC_UNSERIALIZER_ARGS)
 PHP_APCU_API apc_cache_t* apc_cache_create(apc_sma_t* sma, apc_serializer_t* serializer, zend_long size_hint, zend_long gc_ttl, zend_long ttl, zend_long smart, zend_bool defend) {
 	apc_cache_t* cache;
 	zend_long cache_size;
-	zend_long nslots;
+	size_t nslots;
 
 	/* calculate number of slots */
 	nslots = make_prime(size_hint > 0 ? size_hint : 2000);
@@ -332,7 +333,8 @@ static inline zend_bool apc_cache_wlocked_insert(
 	/* make the insertion */
 	{
 		apc_cache_entry_t **entry;
-		zend_ulong h, s;
+		zend_ulong h;
+		size_t s;
 
 		/* calculate hash and entry */
 		apc_cache_hash_slot(cache, key, &h, &s);
@@ -413,7 +415,8 @@ static inline zend_bool apc_cache_store_internal(
 static inline apc_cache_entry_t *apc_cache_rlocked_find_nostat(
 		apc_cache_t *cache, zend_string *key, time_t t) {
 	apc_cache_entry_t *entry;
-	zend_ulong h, s;
+	zend_ulong h;
+	size_t s;
 
 	/* calculate hash and slot */
 	apc_cache_hash_slot(cache, key, &h, &s);
@@ -440,7 +443,8 @@ static inline apc_cache_entry_t *apc_cache_rlocked_find_nostat(
 static inline apc_cache_entry_t *apc_cache_rlocked_find(
 		apc_cache_t *cache, zend_string *key, time_t t) {
 	apc_cache_entry_t *entry;
-	zend_ulong h, s;
+	zend_ulong h;
+	size_t s;
 
 	/* calculate hash and slot */
 	apc_cache_hash_slot(cache, key, &h, &s);
@@ -666,18 +670,16 @@ PHP_APCU_API void apc_cache_detach(apc_cache_t *cache)
 
 /* {{{ apc_cache_wlocked_real_expunge */
 static void apc_cache_wlocked_real_expunge(apc_cache_t* cache) {
+	size_t i;
+
 	/* increment counter */
 	cache->header->nexpunges++;
 
 	/* expunge */
-	{
-		zend_ulong i;
-
-		for (i = 0; i < cache->nslots; i++) {
-			apc_cache_entry_t **entry = &cache->slots[i];
-			while (*entry) {
-				apc_cache_wlocked_remove_entry(cache, entry);
-			}
+	for (i = 0; i < cache->nslots; i++) {
+		apc_cache_entry_t **entry = &cache->slots[i];
+		while (*entry) {
+			apc_cache_wlocked_remove_entry(cache, entry);
 		}
 	}
 
@@ -754,7 +756,7 @@ PHP_APCU_API void apc_cache_default_expunge(apc_cache_t* cache, size_t size)
 	} else {
 		/* check that expunge is necessary */
 		if (available < suitable) {
-			zend_ulong i;
+			size_t i;
 
 			/* look for junk */
 			for (i = 0; i < cache->nslots; i++) {
@@ -959,7 +961,8 @@ retry_update:
 PHP_APCU_API zend_bool apc_cache_delete(apc_cache_t *cache, zend_string *key)
 {
 	apc_cache_entry_t **entry;
-	zend_ulong h, s;
+	zend_ulong h;
+	size_t s;
 
 	if (!cache) {
 		return 0;
@@ -1061,7 +1064,7 @@ PHP_APCU_API zend_bool apc_cache_info(zval *info, apc_cache_t *cache, zend_bool
 	zval gc;
 	zval slots;
 	apc_cache_entry_t *p;
-	zend_ulong i, j;
+	zend_ulong j;
 
 	ZVAL_NULL(info);
 	if (!cache) {
@@ -1091,6 +1094,8 @@ PHP_APCU_API zend_bool apc_cache_info(zval *info, apc_cache_t *cache, zend_bool
 #endif
 
 		if (!limited) {
+			size_t i;
+
 			/* For each hashtable slot */
 			array_init(&list);
 			array_init(&slots);
@@ -1132,7 +1137,8 @@ PHP_APCU_API zend_bool apc_cache_info(zval *info, apc_cache_t *cache, zend_bool
  fetches information about the key provided
 */
 PHP_APCU_API void apc_cache_stat(apc_cache_t *cache, zend_string *key, zval *stat) {
-	zend_ulong h, s;
+	zend_ulong h;
+	size_t s;
 
 	ZVAL_NULL(stat);
 	if (!cache) {
