@@ -15,7 +15,6 @@
   | Authors: Pierre Joye <pierre@php.net>                                |
   +----------------------------------------------------------------------+
  */
-/* $Id$ */
 
 #ifndef APC_WINDOWS_CS_RWLOCK_H
 #define APC_WINDOWS_CS_RWLOCK_H
@@ -24,32 +23,7 @@
 
 #ifdef APC_SRWLOCK_KERNEL
 
-typedef struct _RTL_RWLOCK {
-   RTL_CRITICAL_SECTION rtlCS;
-
-   HANDLE hSharedReleaseSemaphore;
-   UINT   uSharedWaiters;
-
-   HANDLE hExclusiveReleaseSemaphore;
-   UINT   uExclusiveWaiters;
-
-   INT    iNumberActive;
-   HANDLE hOwningThreadId;
-   DWORD  dwTimeoutBoost;
-   PVOID  pDebugInfo;
-} RTL_RWLOCK, *LPRTL_RWLOCK;
-
-#define apc_windows_cs_rwlock_t RTL_RWLOCK
-
-struct apc_windows_cs_rwlock_t {
-    CRITICAL_SECTION cs;
-    LONG writers_waiting_count;
-    LONG readers_waiting_count;
-    DWORD active_writers_readers_flag;
-    HANDLE ready_to_read;
-    HANDLE ready_to_write;
-    DWORD reader_races_lost;
-};
+typedef SRWLOCK apc_windows_cs_rwlock_t;
 
 apc_windows_cs_rwlock_t *apc_windows_cs_create(apc_windows_cs_rwlock_t *lock);
 void apc_windows_cs_destroy(apc_windows_cs_rwlock_t *lock);
@@ -57,9 +31,6 @@ void apc_windows_cs_lock(apc_windows_cs_rwlock_t *lock);
 void apc_windows_cs_rdlock(apc_windows_cs_rwlock_t *lock);
 void apc_windows_cs_unlock_rd(apc_windows_cs_rwlock_t *lock);
 void apc_windows_cs_unlock_wr(apc_windows_cs_rwlock_t *lock);
-# if NONBLOCKING_LOCK_AVAILABLE==1 /* Only in win7/2008 */
-zend_bool apc_pthreadrwlock_nonblocking_lock(apc_windows_cs_rwlock_t *lock);
-# endif
 #endif
 
 #endif
@@ -69,6 +40,6 @@ zend_bool apc_pthreadrwlock_nonblocking_lock(apc_windows_cs_rwlock_t *lock);
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim>600: expandtab sw=4 ts=4 sts=4 fdm=marker
- * vim<600: expandtab sw=4 ts=4 sts=4
+ * vim>600: noexpandtab sw=4 ts=4 sts=4 fdm=marker
+ * vim<600: noexpandtab sw=4 ts=4 sts=4
  */
