@@ -27,22 +27,26 @@
 
  */
 
-/* $Id: php_apc.h 328953 2013-01-03 02:19:19Z rasmus $ */
+#ifndef PHP_APCU_H
+#define PHP_APCU_H
 
-#ifndef PHP_APC_H
-#define PHP_APC_H
-
-#include "apc_php.h"
+#include "apc.h"
 #include "apc_globals.h"
 
-#define PHP_APCU_VERSION "4.0.11"
+#define PHP_APCU_VERSION "5.1.22"
 #define PHP_APCU_EXTNAME "apcu"
 
+PHP_APCU_API zend_bool apc_is_enabled(void);
+
 extern zend_module_entry apcu_module_entry;
 #define apcu_module_ptr &apcu_module_entry
 
 #define phpext_apcu_ptr apcu_module_ptr
 
+#if defined(ZTS) && defined(COMPILE_DL_APCU)
+ZEND_TSRMLS_CACHE_EXTERN();
+#endif
+
 #endif /* PHP_APC_H */
 
 /*
@@ -50,6 +54,6 @@ extern zend_module_entry apcu_module_entry;
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim>600: expandtab sw=4 ts=4 sts=4 fdm=marker
- * vim<600: expandtab sw=4 ts=4 sts=4
+ * vim>600: noexpandtab sw=4 ts=4 sts=4 fdm=marker
+ * vim<600: noexpandtab sw=4 ts=4 sts=4
  */
